//	--/\/--
//Name: Scaled Vehicle Spawns
//Author: NiXiLL
//
//Usage for own bricks:
//  X  Make sure the brick type is set to vehicle spawn.
//  X  Add a vehicleScale field, containing the preferred scale.
//  X  You're done!
//	--------

//Create the mini vehicle spawn package.
package MiniVehicleSpawn
{
	//On vehicle spawn from brick:
	function fxDtsBrick::spawnVehicle(%b)
	{
		//Do the original function.
		Parent::spawnVehicle(%b);
		
		//Get the datablock and store in %data.
		%data=%b.getDatablock();
		
		//Get the needed scale and store in %scale.
		%scale=%data.vehicleScale;
		//If %scale is ""(invalid), make it "1 1 1".
		if(%scale$="") {%scale="1 1 1";}
		
		//If the vehicle has a turret:
		if(isObject(%b.vehicle.turret))
		{
			//Scale the turret.
			%b.vehicle.turret.setScale(%scale);
		}
		
		//Scale the vehicle.
		%b.vehicle.setScale(%scale);
	}
};
ActivatePackage(MiniVehicleSpawn);

datablock fxDtsBrickData(brick1x1VehSpawn : brick1x1fdata)
{
	//General settings
	uiName="Vehicle Spawn (0.1)";
	category="Special";
	subCategory="Mini Spawns";
	//Special settings
	vehicleScale="0.1 0.1 0.1";
	specialBrickType="vehicleSpawn";
	brickType=2;
};

datablock fxDtsBrickData(brick2x2VehSpawn : brick2x2fdata)
{
	//General settings
	uiName="Vehicle Spawn (0.2)";
	category="Special";
	subCategory="Mini Spawns";
	//Special settings
	vehicleScale="0.2 0.2 0.2";
	specialBrickType="vehicleSpawn";
	brickType=2;
};

datablock fxDtsBrickData(brick4x4VehSpawn : brick4x4fdata)
{
	//General settings
	uiName="Vehicle Spawn (0.5)";
	category="Special";
	subCategory="Mini Spawns";
	//Special settings
	vehicleScale="0.5 0.5 0.5";
	specialBrickType="vehicleSpawn";
	brickType=2;
};

//	--/\/--
//Name: Scaled Player Spawns
//Author: NiXiLL
//
//Usage for own bricks:
//  X  Make sure the brick type is set to spawnpoint.
//  X  Add a playerScale field, containing the preferred scale.
//  X  You're done!
//	--------

//If there is no spawnPointGroup, create it.
if(!isObject(spawnPointGroup))
{
	new SimSet(spawnPointGroup);
	missionCleanup.add(spawnPointGroup);
}

//Create the mini player spawn package.
package MiniPlayerSpawn
{
	//On create player:
	function GameConnection::createPlayer(%cl,%pos,%a,%b,%c,%d,%e,%f,%g)
	{
		//If the player is not in a minigame, skip.
		if(!isObject(%cl.minigame)) {return Parent::createPlayer(%cl,%pos,%a,%b,%c,%d,%e,%f,%g);}
		//Get the position of the spawn.
		%pos=getPlayerSpawn(%cl);
		//If it can't find a position, get one using the default way.
		if(%pos$="") {%pos=pickSpawnPoint();}
		//Do the original function.
		%a=Parent::createPlayer(%cl,%pos,%a,%b,%c,%d,%e,%f,%g);
		//If it didn't find a spawnbrick, return.
		if(!isObject($SB)) {return;}
		//Get the datablock and store it in %data.
		%data=$SB.getDatablock();
		//If there is a spawnScale specified:
		if(%data.spawnScale!$="")
		{
			//Set the players scale.
			%cl.player.setScale(%data.spawnScale);
		}
		//Return what it would normally return.
		return %a;
	}
	
	//On brick plant:
	function fxDtsBrick::onPlant(%b)
	{
		//Do the original function.
		Parent::onPlant(%b);
		//If the brick is a spawnpoint.
		if(%b.getDatablock().specialBrickType$="SpawnPoint")
		{
			//add it to our spawnPointGroup.
			SpawnPointGroup.add(%b);
		}
	}
};
ActivatePackage(MiniPlayerSpawn);

function getPlayerSpawn(%c)
{
	//Get the minigame and store in %mini.
	%mini=%c.minigame;
	//Get the number of objects in spawnPointGroup and store in %count.
	%count=SpawnPointGroup.getCount();
	//Set SL to 0.
	%SL=0;
	//Loop all bricks in spawnPointGroup:
	for(%i=0;%i<%count;%i++)
	{
		//Get the current object and store in %obj.
		%obj=spawnPointGroup.getObject(%i);
		//If the minigame settings useAllPlayersBricks is off and the brick is not the owner's.
		if(!%mini.useAllPlayersBricks&&%obj.getGroup().client!=%mini.owner) {continue;}
		//Add the brick to the SL list.
		%SL[%SL]=%obj;
		%SL++;
	}
	
	//If there is something in our list.
	if(%SL)
	{
		//Get a random brick in it.
		%brick=%SL[getRandom(0,%SL-1)];
		//Store the spawnPoint in a global var for later use.
		$SB=%brick;
		//Return the position and the rotation.
		return vectorAdd(%brick.getPosition(),"0 0 0.2") SPC IDToRot(%brick.getAngleID());
	}
	else
	{$SB="";return "";} //No spawns found, return nothing.
}

//Our brick datablocks.
datablock fxDtsBrickData(brick1x1PlaySpawn : brick1x1fdata)
{
	//General settings
	uiName="Player Spawn (0.1)";
	category="Special";
	subCategory="Mini Spawns";
	//Special Settings
	spawnScale="0.1 0.1 0.1";
	specialBrickType="SpawnPoint";
	brickType=1;
};

datablock fxDtsBrickData(brick2x2PlaySpawn : brick2x2fdata)
{
	//General settings
	uiName="Player Spawn (0.2)";
	category="Special";
	subCategory="Mini Spawns";
	//Special settings
	spawnScale="0.2 0.2 0.2";
	specialBrickType="SpawnPoint";
	brickType=1;
};

datablock fxDtsBrickData(brick4x4PlaySpawn : brick4x4fdata)
{
	//General settings
	uiName="Player Spawn (0.5)";
	category="Special";
	subCategory="Mini Spawns";
	//Special Settings
	spawnScale="0.5 0.5 0.5";
	specialBrickType="SpawnPoint";
	brickType=1;
};

//Support
function IDtoRot(%id) //Credits to Randy.
{
	switch(%id)
	{
		case 0:
			%trans = %trans SPC " 1 0 0 0";
		case 1:
			%trans = %trans SPC " 0 0 1" SPC $piOver2;
		case 2:
			%trans = %trans SPC " 0 0 1" SPC $pi;
		case 3:
			%trans = %trans SPC " 0 0 -1" SPC $piOver2;
	}
	return %trans;
}